# Workspace Administration
### On this page
  * [Navigating to the Administration Area](https://help.sap.com/docs/leanix/ea/workspace-administration#navigating-to-the-administration-area)
  * [Configuring Workspace Settings](https://help.sap.com/docs/leanix/ea/workspace-administration#configuring-workspace-settings)
  * [Managing User Access and Permissions](https://help.sap.com/docs/leanix/ea/workspace-administration#managing-user-access-and-permissions)
  * [Switching Your User Role](https://help.sap.com/docs/leanix/ea/workspace-administration#switching-your-user-role)
  * [Enabling Maintenance Mode for a Workspace](https://help.sap.com/docs/leanix/ea/workspace-administration#enabling-maintenance-mode-for-a-workspace)
  * [Finding the Workspace ID](https://help.sap.com/docs/leanix/ea/workspace-administration#finding-the-workspace-id)
  * [Monitoring the Usage and Adoption of SAP LeanIX](https://help.sap.com/docs/leanix/ea/workspace-administration#monitoring-the-usage-and-adoption-of-sap-leanix)


The workspace administration area is a centralized hub for managing and customizing your workspace. As an admin, you can adjust workspace settings to best suit the needs of your team.
